{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Deploy Application" %}{% endblock %}

{% block page_header %}
  {% include 'horizon/common/_page_header.html' with title=_('Deploy Application') %}
{% endblock page_header %}

{% block main %}
  {% include 'applications/_launch.html' %}
{% endblock %}